Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(233)

Unified Diff: third_party/WebKit/Source/core/dom/Node.h

Issue 1858163002: Rename inDocument() to inShadowIncludingDocument() (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebase Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/dom/Node.h
diff --git a/third_party/WebKit/Source/core/dom/Node.h b/third_party/WebKit/Source/core/dom/Node.h
index 5e6f9ec6a79c2f407f85c58fb3cf57cee1084dec..6e3f3b28a565a8a1e414f85c862f1f8b7ab0c327 100644
--- a/third_party/WebKit/Source/core/dom/Node.h
+++ b/third_party/WebKit/Source/core/dom/Node.h
@@ -476,9 +476,9 @@ public:
bool inActiveDocument() const;
// Returns true if this node is associated with a document and is in its associated document's
// node tree, false otherwise.
- bool inDocument() const
+ bool inShadowIncludingDocument() const
{
return getFlag(InDocumentFlag);
}
@@ -571,7 +571,7 @@ public:
// dispatching.
//
// WebKit notifies this callback regardless if the subtree of the node is a document tree or a floating subtree.
// Implementation can determine the type of subtree by seeing insertionPoint->inDocument().
// For a performance reason, notifications are delivered only to ContainerNode subclasses if the insertionPoint is out of document.
//
// There are another callback named didNotifySubtreeInsertionsToDocument(), which is called after all the descendant is notified,
@@ -476,9 +476,9 @@ public:
bool inActiveDocument() const;
- // Returns true if this node is associated with a document and is in its associated document's
+ // Returns true if this node is associated with a shadow-including document and is in its associated document's
// node tree, false otherwise.
@@ -571,7 +571,7 @@ public:
//
// WebKit notifies this callback regardless if the subtree of the node is a document tree or a floating subtree.
- // Implementation can determine the type of subtree by seeing insertionPoint->inDocument().
+ // Implementation can determine the type of subtree by seeing insertionPoint->inShadowIncludingDocument().
// For a performance reason, notifications are delivered only to ContainerNode subclasses if the insertionPoint is out of document.
//
« no previous file with comments | « third_party/WebKit/Source/core/dom/LayoutTreeBuilderTraversal.cpp ('k') | third_party/WebKit/Source/core/dom/Node.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698